@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@
 #include "akregatorconfig.h"
 #include "actions/actions.h"
 #include "urlhandler/webengine/urlhandlerwebengine.h"
-
+#include <qtwebenginewidgetsversion.h>
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineAccessKey>
 #include <KPIMTextEdit/TextToSpeech>
@@ -63,10 +63,12 @@ class AkregatorRequestInterceptor : public QWebEngineUrlRequestInterceptor
     Q_OBJECT
 
 public:
-    explicit AkregatorRequestInterceptor(QObject *parent = nullptr) : QWebEngineUrlRequestInterceptor(parent) {
+    explicit AkregatorRequestInterceptor(QObject *parent = nullptr) : QWebEngineUrlRequestInterceptor(parent)
+    {
     }
 
-    void interceptRequest(QWebEngineUrlRequestInfo &info) override {
+    void interceptRequest(QWebEngineUrlRequestInfo &info) override
+    {
         Q_UNUSED(info);
     }
 };
@@ -77,16 +79,18 @@ ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *p
     , mLastButtonClicked(LeftButton)
     , mViewerPluginToolManager(nullptr)
 {
-    mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
 
     QWebEngineProfile *profile = QWebEngineProfile::defaultProfile();
     mPageEngine = new ArticleViewerWebEnginePage(profile, this);
     profile->setPersistentCookiesPolicy(QWebEngineProfile::ForcePersistentCookies);
 
+#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 13, 0)
     // Needed to workaround crash in webengine, see https://bugreports.qt.io/browse/QTBUG-72260
     auto webEngineUrlInterceptor = new AkregatorRequestInterceptor();
-    profile->setRequestInterceptor(webEngineUrlInterceptor);
     connect(profile, &QObject::destroyed, webEngineUrlInterceptor, &AkregatorRequestInterceptor::deleteLater);
+    profile->setRequestInterceptor(webEngineUrlInterceptor);
+#endif
+    mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
 
     setPage(mPageEngine);
 
@@ -122,7 +126,9 @@ ArticleViewerWebEngine::~ArticleViewerWebEngine()
 
 void ArticleViewerWebEngine::execPrintPreviewPage(QPrinter *printer, int timeout)
 {
-    mPageEngine->execPrintPreviewPage(printer, timeout);
+    if (!mPageEngine->execPrintPreviewPage(printer, timeout)) {
+        qCWarning(AKREGATOR_LOG) << "Impossible to print page";
+    }
 }
 
 void ArticleViewerWebEngine::slotWebPageMutedOrAudibleChanged()
